# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-25 15:43


from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('basemodels', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('sliders', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Dossier',
            fields=[
                ('basemodel_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='basemodels.BaseModel')),
                ('activity', models.TextField(verbose_name='activity')),
                ('start_date', models.DateTimeField(verbose_name='Start Date')),
                ('finish_date', models.DateTimeField(verbose_name='Finish Date')),
            ],
            options={
                'verbose_name': 'Dossier',
                'verbose_name_plural': 'Dossiers',
            },
            bases=('basemodels.basemodel',),
            managers=[
                ('objects', django.db.models.manager.Manager()),
                ('base_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Teacher',
            fields=[
                ('basemodel_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='basemodels.BaseModel')),
                ('biography', models.TextField(verbose_name='Biography')),
                ('start_date', models.DateTimeField(blank=True, null=True, verbose_name='Start Date')),
                ('slider_obj', models.ManyToManyField(to='sliders.Slider', verbose_name='Slider')),
                ('user_obj', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Teacher',
                'verbose_name_plural': 'Teachers',
            },
            bases=('basemodels.basemodel',),
        ),
        migrations.AddField(
            model_name='dossier',
            name='teacher_obj',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='teachers.Teacher', verbose_name='teacher'),
        ),
    ]
