# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-25 15:43


import aparnik.utils.fields
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('basemodels', '0001_initial'),
        ('socials', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Support',
            fields=[
                ('basemodel_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='basemodels.BaseModel')),
                ('title', models.CharField(max_length=255, verbose_name='Title')),
                ('online', models.CharField(blank=True, max_length=255, null=True, verbose_name='Online')),
                ('offline', models.CharField(blank=True, max_length=255, null=True, verbose_name='Offline')),
                ('phone', aparnik.utils.fields.PhoneField(blank=True, max_length=11, null=True, validators=[django.core.validators.RegexValidator(code=b'nomatch', message='phone is not valid, please insert with code', regex=b'^0(?!0)\\d{2}([0-9]{8})$')], verbose_name='Phone')),
                ('online_days', models.CharField(blank=True, max_length=255, null=True, verbose_name='Online Days')),
                ('is_active', models.BooleanField(default=True, verbose_name='Is Active')),
                ('socials', models.ManyToManyField(to='socials.SocialNetwork', verbose_name='Socials')),
            ],
            options={
                'verbose_name': 'Support',
                'verbose_name_plural': 'Supports',
            },
            bases=('basemodels.basemodel',),
        ),
    ]
