# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-03 00:41


from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('courses', '0005_remove_course_is_free'),
        ('progresses', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProgressSummary',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('percentage', models.IntegerField(verbose_name='Percentage')),
                ('model', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='progress_summaries', to='courses.Course', verbose_name='Models')),
                ('user_obj', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='progress_user', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Progress Summary',
                'verbose_name_plural': 'Progress Summary',
            },
        ),
    ]
