# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-08 11:32


from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('files', '0004_file_cover'),
    ]

    operations = [
        migrations.AddField(
            model_name='file',
            name='publish_date',
            field=models.DateTimeField(default=django.utils.timezone.now, verbose_name='\\u062a\\u0627\\u0631\\u06cc\\u062e \\u0627\\u0646\\u062a\\u0634\\u0627\\u0631'),
        ),
    ]
