# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-11 13:51


from django.db import migrations, models
import tagulous.models.fields
import tagulous.models.models


class Migration(migrations.Migration):

    dependencies = [
        ('basemodels', '0005_basemodel_is_show_only_for_super_user'),
    ]

    operations = [
        migrations.CreateModel(
            name='Tagulous_BaseModel_tags',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('slug', models.SlugField()),
                ('count', models.IntegerField(default=0, help_text='Internal counter of how many times this tag is in use')),
                ('protected', models.BooleanField(default=False, help_text='Will not be deleted when the count reaches 0')),
            ],
            options={
                'ordering': ('name',),
                'abstract': False,
            },
            bases=(tagulous.models.models.BaseTagModel, models.Model),
        ),
        migrations.AlterUniqueTogether(
            name='tagulous_basemodel_tags',
            unique_together=set([('slug',)]),
        ),
        migrations.AddField(
            model_name='basemodel',
            name='tags',
            field=tagulous.models.fields.TagField(_set_tag_meta=True, help_text='Enter a comma-separated tag string', to='basemodels.Tagulous_BaseModel_tags'),
        ),
    ]
