# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-25 11:09


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('settings', '0002_auto_20181125_1057'),
    ]

    operations = [
        migrations.AlterField(
            model_name='setting',
            name='value',
            field=models.TextField(verbose_name='Value'),
        ),
    ]
