# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-25 15:43


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('products', '0001_initial'),
        ('files', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='BaseCourse',
            fields=[
                ('product_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='products.Product')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
            ],
            options={
                'verbose_name': 'Base Course',
                'verbose_name_plural': 'Bases Courses',
            },
            bases=('products.product',),
        ),
        migrations.CreateModel(
            name='CourseFile',
            fields=[
                ('file_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='files.File')),
                ('time', models.TimeField(verbose_name='\\u0632\\u0645\\u0627\\u0646')),
                ('sort', models.IntegerField(default=0, verbose_name='Sort')),
            ],
            options={
                'verbose_name': '\\u067e\\u0631\\u0648\\u0646\\u062f\\u0647',
                'verbose_name_plural': 'Files',
            },
            bases=('files.file',),
        ),
    ]
