/* *****************************************************

     WHMCS Printable Invoice CSS Stylesheet
     Created: 1st September 2011
     Last Updated: 20th November 2011
     Version: 1.3

     This file is part of the WHMCS Billing Software
       http://www.whmcs.com/

***************************************************** */
@import url(/static/fonts/IRANSansWebFonts/css/fontiran.css);
/*@font-face {*/
  /*font-family: 'Mirza';*/
  /*src: url('fonts/Mirza.eot?#') format('eot'),*/
       /*url('fonts/Mirza.woff') format('woff'),*/
       /*url('fonts/Mirza.ttf') format('truetype');*/
	   /*font-size:10px;*/
/*}*/

body {
    margin: 30px;
    background-color: #eaeaea;
    direction: rtl;
    font-family: "IRANSans", "Arial" , sans-serif !important;
}

body,td,input,select {
    font-family: "IRANSans", "Arial" , sans-serif;
    font-size: 11px !important;
    color: #000000;
	line-height:1.4em;
}

.clear { 
	clear: both;
}

form {
    margin: 0px;
}

a {
    font-size: 11px;
    color: #1E598A;
    padding: 10px;
}

a:hover {
    text-decoration: none;
}

.textcenter {
    text-align: center;
}

.textright {
    text-align: right;
}

.wrapper {
    margin: 0 auto 30px;
    padding: 30px;
    width: 640px;
    border: #666 solid 1px;
    background-color: #fff;
    border: 1px solid #ccc;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    border-radius: 5px;
	-moz-box-shadow: 0 0 2px rgba(0,0,0,.1);
 	-webkit-box-shadow: 0 0 2px rgba(0,0,0,.1);
 	box-shadow: 0 0 2px rgba(0,0,0,.1);
}

.date, .duedate {
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	background-color: #fff;
	-webkit-box-shadow: 0 1px 3px rgba(0,0,0,.11), inset 0 -2px 2px rgba(0,0,0,.05);
	-moz-box-shadow: 0 1px 3px rgba(0,0,0,.11), inset 0 -2px 2px rgba(0,0,0,.05);
	box-shadow: 0 1px 3px rgba(0,0,0,.11), inset 0 -2px 2px rgba(0,0,0,.05);
	border: solid 1px #cfcfcf;
	float:right;
	font-size:100%;
	padding:7px 12px;
	margin-left:15px;
}

.date strong {
	color:#007cb6;
}
.duedate strong {
	color:#af0000;
}

.header {
    margin: 0 0 15px 0;
    width: 100%;
	-moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    border-radius: 5px;
}

table.address {
	background:#eaeaea;
	width:100%;
	-moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    border-radius: 5px;
}

table.address td {
	background-color: #fff;
	border:1px solid #ddd;
	padding:15px;
	-moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    border-radius: 5px;
	vertical-align:top;
}

table.items {
    width: 100%;
    background-color: #ccc;
    border-spacing: 0;
    border-collapse: separate;
    border-left: 1px solid #ccc;
}

table.items tr.title td {
    margin: 0;
    padding: 2px 12px;
    line-height: 16px;
    border: 1px solid #ccc;
    border-bottom: 0;
    border-left: 0;
	color:#333;
    font-size: 11px;
    font-weight: bold;
	background-color: #fafafa;
	background-image: -webkit-linear-gradient(bottom, rgba(1,2,2,.03), rgba(255,255,255,.03));
	background-image: -moz-linear-gradient(bottom, rgba(1,2,2,.03), rgba(255,255,255,.03));
	background-image: -o-linear-gradient(bottom, rgba(1,2,2,.03), rgba(255,255,255,.03));
	background-image: -ms-linear-gradient(bottom, rgba(1,2,2,.03), rgba(255,255,255,.03));
	background-image: linear-gradient(to top, rgba(1,2,2,.03), rgba(255,255,255,.03));
}

table.items td {
    margin: 0;
    padding: 2px 8px;
    line-height: 15px;
    background-color: #fff;
    border: 1px solid #ccc;
    border-bottom: 0;
    border-left: 0;
}

table.items tr:last-child td {
    border-bottom: 1px solid #ccc;
}

.row {
    margin: 25px 0;
}

.title {
    font-size: 16px;
/*    font-weight: bold;*/
	line-height: 35px;
}

.subtitle {
    font-size: 14px;
    font-weight: bold;
}

.unpaid {
    font-size: 16px;
    color: #cc0000;
    font-weight: bold;
}

.paid {
    font-size: 16px;
    color: #779500;
    font-weight: bold;
}

.refunded {
    font-size: 16px;
    color: #224488;
    font-weight: bold;
}

.cancelled {
    font-size: 16px;
    color: #cccccc;
    font-weight: bold;
}

.collections {
    font-size: 16px;
    color: #ffcc00;
    font-weight: bold;
}

.creditbox {
    margin: 0 auto 15px auto;
    padding: 10px;
    border: 1px dashed #cc0000;
    font-weight: bold;
    background-color: #FBEEEB;
    text-align: center;
    width: 95%;
    color: #cc0000;
	direction:rtl;
}


.btn, i{
background: #ffffff;
	border: 1px solid #cdd1d5;
 color: #515151;
 cursor: pointer;
 display: inline-block;
 font-size: 105%;
-webkit-box-shadow: inset 0px -1px 0px 0px rgba(250,250,250,1);
-moz-box-shadow: inset 0px -1px 0px 0px rgba(250,250,250,1);
box-shadow: inset 0px -1px 0px 0px rgba(250,250,250,1);
 line-height: 21px;
 margin-bottom: 0;
 padding: 6px 13px;
 text-align: center;
 text-decoration:none;
 zoom: 1; 
 border-radius: 3px;
 moz-border-radius: 3px;
 -webkit-border-radius: 3px;
}

.btn-primary,input[type=submit]{
 border-radius: 3px;
 moz-border-radius: 3px;
 -webkit-border-radius: 3px;
 padding: 6px 13px;
background: #008db5;
background: -moz-linear-gradient(top,  #008db5 0%, #008db5 50%, #008db5 100%);
background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#008db5), color-stop(50%,#008db5), color-stop(100%,#008db5));
background: -webkit-linear-gradient(top,  #008db5 0%,#008db5 50%,#008db5 100%);
background: -o-linear-gradient(top,  #008db5 0%,#008db5 50%,#008db5 100%);
background: -ms-linear-gradient(top,  #008db5 0%,#008db5 50%,#008db5 100%);
background: linear-gradient(to bottom,  #008db5 0%,#008db5 50%,#008db5 100%);
filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#008db5', endColorstr='#008db5',GradientType=0 );
-webkit-box-shadow: inset 0px 1px 1px 0px rgba(0,150,187,1), inset 0px -1px 1px 0px rgba(0,150,187,1);;
-moz-box-shadow: inset 0px 1px 1px 0px rgba(0,150,187,1), inset 0px -1px 1px 0px rgba(0,150,187,1);;
box-shadow: inset 0px 1px 1px 0px rgba(0,150,187,1), inset 0px -1px 1px 0px rgba(0,150,187,1);;
 color: #fff;
 border: 1px solid #007697;
}

.btn-success {
background: #28af62;
background: -moz-linear-gradient(top,  #28af62 0%, #27ae60 50%, #27ae60 100%, #27ae60 100%);
background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#28af62), color-stop(50%,#27ae60), color-stop(100%,#27ae60), color-stop(100%,#27ae60));
background: -webkit-linear-gradient(top,  #28af62 0%,#27ae60 50%,#27ae60 100%,#27ae60 100%);
background: -o-linear-gradient(top,  #28af62 0%,#27ae60 50%,#27ae60 100%,#27ae60 100%);
background: -ms-linear-gradient(top,  #28af62 0%,#27ae60 50%,#27ae60 100%,#27ae60 100%);
background: linear-gradient(to bottom,  #28af62 0%,#27ae60 50%,#27ae60 100%,#27ae60 100%);
filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#28af62', endColorstr='#27ae60',GradientType=0 );
-webkit-box-shadow: inset 0px 1px 1px 0px rgba(42,181,105,1), inset 0px -1px 1px 0px rgba(37,165,91,1);;
-moz-box-shadow: inset 0px 1px 1px 0px rgba(42,181,105,1), inset 0px -1px 1px 0px rgba(37,165,91,1);;
box-shadow: inset 0px 1px 1px 0px rgba(42,181,105,1), inset 0px -1px 1px 0px rgba(37,165,91,1);
border: 1px solid #25a55b;
color: #fff;
}

.btn:hover {
 background: #eee;
}
.btn-primary:hover {
 background: #00719f;
}
.btn-success:hover {
 background: #5ba000;
}

input[type=text], input[type=password], select, textarea, input[type=email], input[type=file] {
 background-color: #fff;
 box-shadow: 0 2px 2px rgba(255,255,255,.1), inset 1px 2px 0 rgba(207,211,218,.15);border: 1px solid #ccc;
 -moz-box-shadow: 0 2px 2px rgba(255,255,255,.1), inset 1px 2px 0 rgba(207,211,218,.15);border: 1px solid #ccc;
 -webkit-box-shadow: 0 2px 2px rgba(255,255,255,.1), inset 1px 2px 0 rgba(207,211,218,.15);border: 1px solid #ccc;
 padding: 6px;
 border: 1px solid #bbcad1;
 -moz-transition: -moz-box-shadow 0.3s;
 -webkit-transition: -webkit-box-shadow 0.3s;
 transition: box-shadow 0.3s;
 color: #666;
}
input:focus, select:focus, textarea:focus {
 border: solid 1px #0f90c4;
 -webkit-box-shadow: 0 0 6px rgba(6,152,255,.35);
 -moz-box-shadow: 0 0 6px rgba(6,152,255,.35);
 box-shadow: 0 0 6px rgba(6,152,255,.35);
 outline: none;
}

input:disabled, select:disabled, textarea::disabled {
 filter: Alpha(opacity=60);
 opacity: 0.6;
}

input[type="file"], input[type="file"]:focus {
 background: 0;
 border:0;
 -webkit-box-shadow:none;
 -moz-box-shadow:none;
 box-shadow:none;
 padding: 0;
}

input[type="checkbox"] {
 background: none;
 border: 0;
 -webkit-border-radius: 0;
 -moz-border-radius: 0;
 border-radius: 0;
 -webkit-box-shadow: none;
 -moz-box-shadow: none;
 box-shadow: none;
 padding: 0;
 width: auto !important;
}

.footer_text span{
    color: #f5f5f5;
    font-size: 11px;
    font-weight: 600;
}

.invoice_part_title{
    width: 100%;
    height: 20px;
    border: #666 solid 1px;
    border-radius: 3px;
    margin: 10px 0;
    text-align: center;
}

.invoice_part_title span{
    line-height: 18px;
    font-size: 10px;
    font-weight: bold;
}

.invoice_seller_title{
    font-weight: bold;
    font-size: 9px;
}

.samfony_invoice_wrapper{
    width: 940px ;
}

.samfony_mobile_show{
    width: 100% !important;
    padding: 0 !important;
    margin-top: 10px;
    display: none;
}

@media only screen and (max-device-width: 500px){
    .samfony_mobile_hidden{
        display: none !important;
    }

    .samfony_invoice_wrapper{
        width: unset;
    }

    .samfony_mobile_show{
        width: 100% !important;
        padding: 0 !important;
        margin-top: 10px;
        display: block;
    }

    .samfony_invoice_header td{
        line-height: 2em;
        padding: 10px;
    }

    .invoice_gateway_title_mobile{
        padding: 10px 0 !important;
        border: #666 solid 1px;
        border-radius: 3px;
        margin: 10px 0;
        text-align: center;
    }
}

.paysuccess:before
{
    content:"\2713 پرداخت شد";
    position:absolute;
    margin: 0 6em;
    font-family:IRANSans,sans-serif;
    -webkit-transform: rotate(-30deg); /* Safari */
    -moz-transform: rotate(-30deg); /* Firefox */
    -ms-transform: rotate(-30deg); /* IE */
    -o-transform: rotate(-30deg); /* Opera */
    transform: rotate(-30deg);
    font-size:4em;
    font-weight: 700;
    color:green;
    background:#fff;
    border:solid 4px green;
    padding:1em;
    border-radius:8px;
    filter:alpha(opacity=10);
    opacity:0.4;
}

.paywaiting:before
{
    content:"\2717 در انتظار پرداخت";
    position:absolute;
    margin: 0 6em;
    font-family:IRANSans,sans-serif;
    -webkit-transform: rotate(-30deg); /* Safari */
    -moz-transform: rotate(-30deg); /* Firefox */
    -ms-transform: rotate(-30deg); /* IE */
    -o-transform: rotate(-30deg); /* Opera */
    transform: rotate(-30deg);
    font-size:4em;
    font-weight: 700;
    color:darkred;
    background:#fff;
    border:solid 4px darkred;
    padding:1em;
    border-radius:8px;
    filter:alpha(opacity=10);
    opacity:0.4;
}
