# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-13 17:13


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('addresses', '0001_initial'),
        ('orders', '0002_auto_20181026_1301'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='address_obj',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='addresses.UserAddress', verbose_name='Order Address'),
        ),
    ]
