# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-08-13 21:29


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aparnik_users', '0003_user_verify_mobile'),
    ]

    operations = [
        migrations.AddField(
            model_name='devicelogin',
            name='device_type',
            field=models.CharField(choices=[('a', 'Android'), ('i', 'iOS')], default='a', max_length=1, verbose_name='Device Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='devicelogin',
            name='is_active',
            field=models.BooleanField(default=True, verbose_name='Is Active'),
        ),
    ]
