# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-09 23:20


import ckeditor_uploader.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('filefields', '0004_filefield_title'),
        ('basemodels', '0004_auto_20181103_2233'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='News',
            fields=[
                ('basemodel_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='basemodels.BaseModel')),
                ('title', models.CharField(max_length=200, verbose_name='\\u0639\\u0646\\u0648\\u0627\\u0646')),
                ('slug', models.SlugField(allow_unicode=True, max_length=300, unique=True, verbose_name='Slug')),
                ('content', ckeditor_uploader.fields.RichTextUploadingField(verbose_name='\\u0645\\u062d\\u062a\\u0648\\u0627')),
                ('is_published', models.BooleanField(default=True, verbose_name='Is Published')),
                ('publish_date', models.DateTimeField(default=django.utils.timezone.now, null=True, verbose_name='\\u062a\\u0627\\u0631\\u06cc\\u062e \\u0627\\u0646\\u062a\\u0634\\u0627\\u0631')),
                ('cover_images', models.ManyToManyField(to='filefields.FileField', verbose_name='Cover Images')),
                ('user_obj', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='\\u06a9\\u0627\\u0631\\u0628\\u0631')),
            ],
            options={
                'verbose_name': 'News',
                'manager_inheritance_from_future': True,
                'verbose_name_plural': 'NEWS',
            },
            bases=('basemodels.basemodel',),
        ),
    ]
