# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-28 21:16


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('products', '0003_remove_product_slider_obj'),
        ('sliders', '0002_slidersegment'),
    ]

    operations = [
        migrations.AddField(
            model_name='product',
            name='slider_segment_obj',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='products_sliders', to='sliders.SliderSegment', verbose_name='Slider Segment'),
        ),
    ]
