# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-21 09:50


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('managements', '0004_fieldlist_group'),
    ]

    operations = [
        migrations.AlterField(
            model_name='fieldlist',
            name='group',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='auth.Group', verbose_name='group'),
        ),
    ]
