# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 12:06


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('payments', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Bank',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.IntegerField(default=-2, verbose_name='Status')),
                ('authority_id', models.CharField(max_length=255, verbose_name='Authority ID')),
                ('ref_id', models.CharField(blank=True, max_length=255, null=True, verbose_name='Bank Reference ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created At')),
                ('update_at', models.DateTimeField(auto_now=True, verbose_name='Update At')),
                ('payment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='payments.Payment', verbose_name='Payment')),
            ],
            options={
                'ordering': ['created_at'],
                'verbose_name': 'Bank',
                'verbose_name_plural': 'Banks',
            },
        ),
    ]
