# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-14 15:37


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0002_page_english_title'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='is_show_in_home',
            field=models.BooleanField(default=True, verbose_name='Is Show in home'),
        ),
    ]
