# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-17 20:59


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0003_order_address_obj'),
    ]

    operations = [
        migrations.AddField(
            model_name='orderitem',
            name='is_tax',
            field=models.BooleanField(default=False, verbose_name='Is Tax'),
        ),
    ]
