

@font-face {
    font-family: 'IRANSans';
    src: url('../fonts/IRANSansWeb_Bold.woff');
    font-weight: 800;
    font-style: normal;
}



@font-face {
    font-family: 'IRANSans';
    src: url('../fonts/IRANSansWeb_Medium.woff');
    font-weight: 700;
    font-style: normal;
}

@font-face {
    font-family: 'IRANSans';
    src: url('../fonts/IRANSansWeb.woff');
    font-weight: 600;
    font-style: normal;
}

@font-face {
    font-family: 'IRANSans';
    src: url('../fonts/IRANSansWeb_Light.woff');
    font-weight: 400;
    font-style: normal;
}

@font-face {
    font-family: 'IRANSans';
    src: url('../fonts/IRANSansWeb_UltraLight.woff');
    font-weight: 200;
    font-style: normal;
}