# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 12:06


from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('basemodels', '0001_initial'),
        ('orders', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Payment',
            fields=[
                ('basemodel_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='basemodels.BaseModel')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, verbose_name='Reference ID')),
                ('bank_reference', models.CharField(blank=True, editable=False, max_length=50, null=True, verbose_name='Bank Reference ID')),
                ('method', models.CharField(choices=[('b', 'Bank'), ('w', 'Wallet')], editable=False, max_length=3, verbose_name='Method payment')),
                ('status', models.CharField(choices=[('c', 'Cancel'), ('cs', 'Cancel by system'), ('cs', 'Cancel by user after pay begin'), ('co', 'Complete'), ('w', 'Waiting')], editable=False, max_length=10, verbose_name='Status')),
                ('call_back_url', models.CharField(blank=True, editable=False, max_length=255, null=True, verbose_name='Call Back URL')),
                ('order_obj', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='payments', to='orders.Order', verbose_name='Order')),
                ('user', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'payment',
                'verbose_name_plural': 'Payments',
            },
            bases=('basemodels.basemodel',),
        ),
    ]
