# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-05-01 17:10


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filefields', '0006_auto_20190501_1142'),
    ]

    operations = [
        migrations.AddField(
            model_name='filefield',
            name='seconds',
            field=models.BigIntegerField(default=0, verbose_name='\\u0632\\u0645\\u0627\\u0646'),
        ),
    ]
